@@ -14,6 +14,7 @@ PATH=/sbin:/bin
 FSCK_LOGFILE=/var/log/fsck/checkfs
 [ "$FSCKFIX" ] || FSCKFIX=no
 . /lib/init/vars.sh
+. /lib/init/usplash-fsck-functions.sh
 
 . /lib/lsb/init-functions
 
@@ -79,8 +80,18 @@ Continuing with system boot in 5 seconds."
 		if [ "$VERBOSE" = no ]
 		then
 			log_action_begin_msg "Checking file systems"
-			logsave -s $FSCK_LOGFILE fsck $spinner -R -A $fix $force $FSCKTYPES_OPT
-			FSCKCODE=$?
+                        if pidof usplash; then
+                            PROGRESS_FILE=`mktemp` || exit 1
+                            set -m
+                            logsave -s $FSCK_LOGFILE fsck -C3 -R -A $fix $force $FSCKTYPES_OPT >/dev/console 2>&1 3>$PROGRESS_FILE &
+                            set +m
+                            usplash_progress "$PROGRESS_FILE"
+                            rm -f $PROGRESS_FILE
+                        else
+                            logsave -s $FSCK_LOGFILE fsck $spinner -R -A $fix $force $FSCKTYPES_OPT
+                            FSCKCODE=$?
+                        fi
+
 			if [ "$FSCKCODE" -gt 1 ]
 			then
 				log_action_end_msg 1 "code $FSCKCODE"
