@@ -26,6 +26,9 @@ do_start () {
 	#
 	domount sysfs "" /sys -onodev,noexec,nosuid
 
+	# Mount /var/run and /var/lock as tmpfs.
+	domount tmpfs "" /var/run -omode=0755,nodev,noexec,nosuid
+	domount tmpfs "" /var/lock -omode=1777,nodev,noexec,nosuid
 
 	# Mount spufs, if Cell Broadband processor is detected
 	if mountpoint -q /proc && grep -qs '^cpu.*Cell' /proc/cpuinfo; then
@@ -38,6 +41,10 @@ do_start () {
 		[ -e "$file" ] || continue
 		cp -a "$file" "/var/run/${x#/dev/.initramfs/varrun/}"
 	done
+
+	if [ ! -d /var/run/sendsigs.omit.d/ ]; then
+		mkdir /var/run/sendsigs.omit.d/
+	fi
 }
 
 case "$1" in
