@@ -15,6 +15,7 @@ FSCK_LOGFILE=/var/log/fsck/checkroot
 [ "$FSCKFIX" ] || FSCKFIX=no
 [ "$SULOGIN" ] || SULOGIN=no
 . /lib/init/vars.sh
+. /lib/init/usplash-fsck-functions.sh
 
 . /lib/lsb/init-functions
 
@@ -195,6 +196,9 @@ Will restart in 5 seconds."
 	# If not, we're not gonna run our check
 	if which on_ac_power >/dev/null 2>&1 && [ "$rootcheck" = yes ]
 	then
+		if [ -d /proc/acpi ]; then
+			modprobe ac >/dev/null 2>&1
+		fi
 		on_ac_power >/dev/null 2>&1
 		if [ "$?" -eq 1 ]
 		then
@@ -271,8 +275,17 @@ Will restart in 5 seconds."
 		if [ "$VERBOSE" = no ]
 		then
 			log_action_begin_msg "Checking root file system"
-			logsave -s $FSCK_LOGFILE fsck $spinner $force $fix -t $roottype $rootdev
-			FSCKCODE=$?
+                        if [ "$roottype" = "ext2" -o "$roottype" = "ext3" ] && pidof usplash; then
+                            PROGRESS_FILE=`mktemp -p /var/run` || PROGRESS_FILE=/var/run/checkroot_fsck
+                            set -m
+                            logsave -s $FSCK_LOGFILE fsck -C3 $force $fix -t $roottype $rootdev >/dev/console 2>&1 3>$PROGRESS_FILE &
+                            set +m
+                            usplash_progress "$PROGRESS_FILE"
+                            rm -f $PROGRESS_FILE
+                        else
+                            logsave -s $FSCK_LOGFILE fsck $spinner $force $fix -t $roottype $rootdev
+                            FSCKCODE=$?
+                        fi
 			if [ "$FSCKCODE" = 0 ]
 			then
 				log_action_end_msg 0
