@@ -82,7 +82,7 @@ tie %Config, 'Config', {
     ldlibpthname => 'LD_LIBRARY_PATH',
     libpth => '/usr/local/lib /lib /usr/lib',
     osname => 'linux',
-    osvers => '2.6.15.7',
+    osvers => '2.6.24-19-server',
     path_sep => ':',
     privlibexp => '/usr/share/perl/5.8',
     scriptdir => '/usr/bin',
