@@ -641,7 +641,7 @@ class Pdb(bdb.Bdb, cmd.Cmd):
         sys.settrace(None)
         globals = self.curframe.f_globals
         locals = self.curframe.f_locals
-        p = Pdb()
+        p = Pdb(self.completekey, self.stdin, self.stdout)
         p.prompt = "(%s) " % self.prompt.strip()
         print >>self.stdout, "ENTERING RECURSIVE DEBUGGER"
         sys.call_tracing(p.run, (arg, globals, locals))
@@ -1123,7 +1123,7 @@ see no sign that the breakpoint was reached.
         # Start with fresh empty copy of globals and locals and tell the script
         # that it's being run as __main__ to avoid scripts being able to access
         # the pdb.py namespace.
-        globals_ = {"__name__" : "__main__"}
+        globals_ = {"__name__" : "__main__", "__file__" : filename}
         locals_ = globals_
 
         # When bdb sets tracing, a number of call and line events happens
